# This file was auto-generated by Fern from our API Definition.

from .types import (
    ActionModel,
    ActionParametersModel,
    ActionResponseModel,
    AgentEnvironmentVariable,
    AgentSchema,
    AgentState,
    AgentStateToolRulesItem,
    AgentType,
    AppAuthScheme,
    AppAuthSchemeAuthMode,
    AppModel,
    AssistantMessage,
    AssistantMessageContent,
    Audio,
    AuthRequest,
    AuthResponse,
    AuthSchemeField,
    Block,
    BlockUpdate,
    ChatCompletionAssistantMessageParam,
    ChatCompletionAssistantMessageParamContent,
    ChatCompletionAssistantMessageParamContentItem,
    ChatCompletionAudioParam,
    ChatCompletionAudioParamFormat,
    ChatCompletionAudioParamVoice,
    ChatCompletionContentPartImageParam,
    ChatCompletionContentPartInputAudioParam,
    ChatCompletionContentPartRefusalParam,
    ChatCompletionContentPartTextParam,
    ChatCompletionDeveloperMessageParam,
    ChatCompletionDeveloperMessageParamContent,
    ChatCompletionFunctionCallOptionParam,
    ChatCompletionFunctionMessageParam,
    ChatCompletionMessageToolCall,
    ChatCompletionMessageToolCallParam,
    ChatCompletionNamedToolChoiceParam,
    ChatCompletionPredictionContentParam,
    ChatCompletionPredictionContentParamContent,
    ChatCompletionStreamOptionsParam,
    ChatCompletionSystemMessageParam,
    ChatCompletionSystemMessageParamContent,
    ChatCompletionToolMessageParam,
    ChatCompletionToolMessageParamContent,
    ChatCompletionToolParam,
    ChatCompletionUserMessageParam,
    ChatCompletionUserMessageParamContent,
    ChatCompletionUserMessageParamContentItem,
    ChildToolRule,
    CompletionCreateParamsNonStreaming,
    CompletionCreateParamsNonStreamingFunctionCall,
    CompletionCreateParamsNonStreamingMessagesItem,
    CompletionCreateParamsNonStreamingModalitiesItem,
    CompletionCreateParamsNonStreamingModel,
    CompletionCreateParamsNonStreamingReasoningEffort,
    CompletionCreateParamsNonStreamingResponseFormat,
    CompletionCreateParamsNonStreamingServiceTier,
    CompletionCreateParamsNonStreamingStop,
    CompletionCreateParamsNonStreamingToolChoice,
    CompletionCreateParamsStreaming,
    CompletionCreateParamsStreamingFunctionCall,
    CompletionCreateParamsStreamingMessagesItem,
    CompletionCreateParamsStreamingModalitiesItem,
    CompletionCreateParamsStreamingModel,
    CompletionCreateParamsStreamingReasoningEffort,
    CompletionCreateParamsStreamingResponseFormat,
    CompletionCreateParamsStreamingServiceTier,
    CompletionCreateParamsStreamingStop,
    CompletionCreateParamsStreamingToolChoice,
    ComponentsSchemasTextContent,
    ConditionalToolRule,
    ConflictErrorBody,
    ContextWindowOverview,
    ContinueToolRule,
    CoreMemoryBlockSchema,
    CreateBlock,
    DynamicManager,
    E2BSandboxConfig,
    EmbeddingConfig,
    EmbeddingConfigEmbeddingEndpointType,
    File,
    FileFile,
    FileMetadata,
    FunctionCall,
    FunctionDefinitionInput,
    FunctionDefinitionOutput,
    FunctionOutput,
    FunctionTool,
    Group,
    GroupCreate,
    GroupCreateManagerConfig,
    Health,
    HttpValidationError,
    Identity,
    IdentityCreate,
    IdentityProperty,
    IdentityPropertyType,
    IdentityPropertyValue,
    IdentityType,
    ImageUrl,
    ImageUrlDetail,
    InitToolRule,
    InputAudio,
    InputAudioFormat,
    InternalServerErrorBody,
    Job,
    JobStatus,
    JobType,
    JsonSchema,
    LettaMessageContentUnion,
    LettaMessageUnion,
    LettaRequest,
    LettaRequestConfig,
    LettaResponse,
    LettaStreamingRequest,
    LettaUsageStatistics,
    LlmConfig,
    LlmConfigModelEndpointType,
    LocalSandboxConfig,
    ManagerType,
    MaxCountPerStepToolRule,
    McpServerType,
    McpTool,
    Memory,
    Message,
    MessageContentItem,
    MessageCreate,
    MessageCreateContent,
    MessageCreateRole,
    MessageRole,
    MessageSchema,
    NotFoundErrorBody,
    NotFoundErrorBodyMessage,
    OmittedReasoningContent,
    OpenaiTypesChatChatCompletionMessageToolCallParamFunction,
    OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction,
    OpenaiTypesChatCompletionCreateParamsFunction,
    Organization,
    OrganizationCreate,
    ParameterProperties,
    ParametersSchema,
    Passage,
    PipRequirement,
    Provider,
    ReasoningContent,
    ReasoningMessage,
    ReasoningMessageSource,
    RedactedReasoningContent,
    ResponseFormatJsonObject,
    ResponseFormatJsonSchema,
    ResponseFormatText,
    RoundRobinManager,
    Run,
    SandboxConfig,
    SandboxConfigCreate,
    SandboxConfigCreateConfig,
    SandboxConfigUpdate,
    SandboxConfigUpdateConfig,
    SandboxEnvironmentVariable,
    SandboxEnvironmentVariableCreate,
    SandboxEnvironmentVariableUpdate,
    SandboxType,
    Source,
    SseServerConfig,
    StdioServerConfig,
    Step,
    SupervisorManager,
    SystemMessage,
    TagSchema,
    TerminalToolRule,
    TextContent,
    Tool,
    ToolCall,
    ToolCallContent,
    ToolCallDelta,
    ToolCallMessage,
    ToolCallMessageToolCall,
    ToolCreate,
    ToolEnvVarSchema,
    ToolJsonSchema,
    ToolReturn,
    ToolReturnContent,
    ToolReturnMessage,
    ToolReturnMessageStatus,
    ToolReturnStatus,
    ToolRuleSchema,
    ToolSchema,
    ToolType,
    UpdateAssistantMessage,
    UpdateAssistantMessageContent,
    UpdateReasoningMessage,
    UpdateSystemMessage,
    UpdateUserMessage,
    UpdateUserMessageContent,
    UsageStatistics,
    User,
    UserCreate,
    UserMessage,
    UserMessageContent,
    UserUpdate,
    ValidationError,
    ValidationErrorLocItem,
    WebSearchOptions,
    WebSearchOptionsSearchContextSize,
    WebSearchOptionsUserLocation,
    WebSearchOptionsUserLocationApproximate,
)
from .errors import ConflictError, InternalServerError, NotFoundError, UnprocessableEntityError
from . import (
    agents,
    blocks,
    groups,
    health,
    identities,
    jobs,
    models,
    providers,
    runs,
    sources,
    steps,
    tag,
    templates,
    tools,
    voice,
)
from .agents import (
    AgentsSearchRequestSearchItem,
    AgentsSearchRequestSearchItemField,
    AgentsSearchRequestSearchItemOne,
    AgentsSearchRequestSearchItemOneOperator,
    AgentsSearchRequestSearchItemZero,
    AgentsSearchResponse,
    AgentsSearchResponseAgentsItem,
    AgentsSearchResponseAgentsItemAgentType,
    AgentsSearchResponseAgentsItemBaseTemplateId,
    AgentsSearchResponseAgentsItemBaseTemplateIdItem,
    AgentsSearchResponseAgentsItemCreatedAt,
    AgentsSearchResponseAgentsItemCreatedAtItem,
    AgentsSearchResponseAgentsItemCreatedById,
    AgentsSearchResponseAgentsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemDescription,
    AgentsSearchResponseAgentsItemDescriptionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemIdentityIds,
    AgentsSearchResponseAgentsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemLlmConfig,
    AgentsSearchResponseAgentsItemLlmConfigHandle,
    AgentsSearchResponseAgentsItemLlmConfigHandleItem,
    AgentsSearchResponseAgentsItemLlmConfigMaxTokens,
    AgentsSearchResponseAgentsItemLlmConfigMaxTokensItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
    AgentsSearchResponseAgentsItemMemory,
    AgentsSearchResponseAgentsItemMemoryBlocksItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
    AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemMemoryPromptTemplate,
    AgentsSearchResponseAgentsItemMessageBufferAutoclear,
    AgentsSearchResponseAgentsItemMessageIds,
    AgentsSearchResponseAgentsItemMessageIdsItem,
    AgentsSearchResponseAgentsItemMetadata,
    AgentsSearchResponseAgentsItemMetadataItem,
    AgentsSearchResponseAgentsItemMultiAgentGroup,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIds,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentId,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentIdItem,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsManagerType,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsMaxTurns,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsMaxTurnsItem,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsTerminationToken,
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsTerminationTokenItem,
    AgentsSearchResponseAgentsItemMultiAgentGroupItem,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIds,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentIdItem,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken,
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem,
    AgentsSearchResponseAgentsItemOrganizationId,
    AgentsSearchResponseAgentsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemProjectId,
    AgentsSearchResponseAgentsItemProjectIdItem,
    AgentsSearchResponseAgentsItemSourcesItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
    AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemDescription,
    AgentsSearchResponseAgentsItemSourcesItemDescriptionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemSourcesItemId,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemMetadata,
    AgentsSearchResponseAgentsItemSourcesItemMetadataItem,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemTemplateId,
    AgentsSearchResponseAgentsItemTemplateIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariables,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemToolRules,
    AgentsSearchResponseAgentsItemToolRulesItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemFour,
    AgentsSearchResponseAgentsItemToolRulesItemFourType,
    AgentsSearchResponseAgentsItemToolRulesItemItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemItemFour,
    AgentsSearchResponseAgentsItemToolRulesItemItemFourType,
    AgentsSearchResponseAgentsItemToolRulesItemItemMaxCountLimit,
    AgentsSearchResponseAgentsItemToolRulesItemItemMaxCountLimitType,
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwoType,
    AgentsSearchResponseAgentsItemToolRulesItemMaxCountLimit,
    AgentsSearchResponseAgentsItemToolRulesItemMaxCountLimitType,
    AgentsSearchResponseAgentsItemToolRulesItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemTwoType,
    AgentsSearchResponseAgentsItemToolsItem,
    AgentsSearchResponseAgentsItemToolsItemArgsJsonSchema,
    AgentsSearchResponseAgentsItemToolsItemArgsJsonSchemaItem,
    AgentsSearchResponseAgentsItemToolsItemCreatedById,
    AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemDescription,
    AgentsSearchResponseAgentsItemToolsItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolsItemJsonSchema,
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemMetadata,
    AgentsSearchResponseAgentsItemToolsItemMetadataItem,
    AgentsSearchResponseAgentsItemToolsItemName,
    AgentsSearchResponseAgentsItemToolsItemNameItem,
    AgentsSearchResponseAgentsItemToolsItemOrganizationId,
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolsItemSourceCode,
    AgentsSearchResponseAgentsItemToolsItemSourceCodeItem,
    AgentsSearchResponseAgentsItemToolsItemSourceType,
    AgentsSearchResponseAgentsItemToolsItemSourceTypeItem,
    AgentsSearchResponseAgentsItemToolsItemToolType,
    AgentsSearchResponseAgentsItemUpdatedAt,
    AgentsSearchResponseAgentsItemUpdatedAtItem,
    CreateAgentRequestToolRulesItem,
    UpdateAgentToolRulesItem,
)
from .client import AsyncLetta, Letta
from .environment import LettaEnvironment
from .templates import (
    TemplatesCreateAgentsResponse,
    TemplatesCreateAgentsResponseAgentsItem,
    TemplatesCreateAgentsResponseAgentsItemAgentType,
    TemplatesCreateAgentsResponseAgentsItemBaseTemplateId,
    TemplatesCreateAgentsResponseAgentsItemBaseTemplateIdItem,
    TemplatesCreateAgentsResponseAgentsItemCreatedAt,
    TemplatesCreateAgentsResponseAgentsItemCreatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemDescription,
    TemplatesCreateAgentsResponseAgentsItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandle,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsResponseAgentsItemIdentityIds,
    TemplatesCreateAgentsResponseAgentsItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfig,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigHandle,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigHandleItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokens,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokensItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpoint,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointType,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapper,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapperItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigTemperature,
    TemplatesCreateAgentsResponseAgentsItemMemory,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescription,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemId,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemIsTemplate,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabel,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabelItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLimit,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadata,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadataItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemName,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemNameItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryPromptTemplate,
    TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear,
    TemplatesCreateAgentsResponseAgentsItemMessageIds,
    TemplatesCreateAgentsResponseAgentsItemMessageIdsItem,
    TemplatesCreateAgentsResponseAgentsItemMetadata,
    TemplatesCreateAgentsResponseAgentsItemMetadataItem,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentId,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentIdItem,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerType,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurns,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurnsItem,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationToken,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationTokenItem,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentIdItem,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken,
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem,
    TemplatesCreateAgentsResponseAgentsItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemProjectId,
    TemplatesCreateAgentsResponseAgentsItemProjectIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAt,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemDescription,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfig,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemId,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadata,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadataItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAt,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemTemplateId,
    TemplatesCreateAgentsResponseAgentsItemTemplateIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemToolRules,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildren,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildrenType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemFour,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemFourType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildren,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildrenType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFour,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFourType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimit,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimitType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOne,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwo,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwoType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimit,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimitType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemOne,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemOneType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwo,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwoType,
    TemplatesCreateAgentsResponseAgentsItemToolsItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchema,
    TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchemaItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemDescription,
    TemplatesCreateAgentsResponseAgentsItemToolsItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema,
    TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchemaItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemMetadata,
    TemplatesCreateAgentsResponseAgentsItemToolsItemMetadataItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemName,
    TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCodeItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceTypeItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemToolType,
    TemplatesCreateAgentsResponseAgentsItemUpdatedAt,
    TemplatesCreateAgentsResponseAgentsItemUpdatedAtItem,
)
from .tools import (
    AddMcpServerRequest,
    AddMcpServerResponseItem,
    DeleteMcpServerResponseItem,
    ListMcpServersResponseValue,
)
from .version import __version__
from .voice import CreateVoiceChatCompletionsRequest

__all__ = [
    "ActionModel",
    "ActionParametersModel",
    "ActionResponseModel",
    "AddMcpServerRequest",
    "AddMcpServerResponseItem",
    "AgentEnvironmentVariable",
    "AgentSchema",
    "AgentState",
    "AgentStateToolRulesItem",
    "AgentType",
    "AgentsSearchRequestSearchItem",
    "AgentsSearchRequestSearchItemField",
    "AgentsSearchRequestSearchItemOne",
    "AgentsSearchRequestSearchItemOneOperator",
    "AgentsSearchRequestSearchItemZero",
    "AgentsSearchResponse",
    "AgentsSearchResponseAgentsItem",
    "AgentsSearchResponseAgentsItemAgentType",
    "AgentsSearchResponseAgentsItemBaseTemplateId",
    "AgentsSearchResponseAgentsItemBaseTemplateIdItem",
    "AgentsSearchResponseAgentsItemCreatedAt",
    "AgentsSearchResponseAgentsItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemCreatedById",
    "AgentsSearchResponseAgentsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemDescription",
    "AgentsSearchResponseAgentsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemIdentityIds",
    "AgentsSearchResponseAgentsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemLlmConfig",
    "AgentsSearchResponseAgentsItemLlmConfigHandle",
    "AgentsSearchResponseAgentsItemLlmConfigHandleItem",
    "AgentsSearchResponseAgentsItemLlmConfigMaxTokens",
    "AgentsSearchResponseAgentsItemLlmConfigMaxTokensItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpoint",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointType",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapper",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "AgentsSearchResponseAgentsItemLlmConfigTemperature",
    "AgentsSearchResponseAgentsItemMemory",
    "AgentsSearchResponseAgentsItemMemoryBlocksItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescription",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabel",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLimit",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemName",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemMemoryPromptTemplate",
    "AgentsSearchResponseAgentsItemMessageBufferAutoclear",
    "AgentsSearchResponseAgentsItemMessageIds",
    "AgentsSearchResponseAgentsItemMessageIdsItem",
    "AgentsSearchResponseAgentsItemMetadata",
    "AgentsSearchResponseAgentsItemMetadataItem",
    "AgentsSearchResponseAgentsItemMultiAgentGroup",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIds",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentId",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentIdItem",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsManagerType",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsMaxTurns",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsMaxTurnsItem",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsTerminationToken",
    "AgentsSearchResponseAgentsItemMultiAgentGroupAgentIdsTerminationTokenItem",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItem",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIds",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentIdItem",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken",
    "AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem",
    "AgentsSearchResponseAgentsItemOrganizationId",
    "AgentsSearchResponseAgentsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemProjectId",
    "AgentsSearchResponseAgentsItemProjectIdItem",
    "AgentsSearchResponseAgentsItemSourcesItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedById",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemDescription",
    "AgentsSearchResponseAgentsItemSourcesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemSourcesItemId",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemMetadata",
    "AgentsSearchResponseAgentsItemSourcesItemMetadataItem",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationId",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemTemplateId",
    "AgentsSearchResponseAgentsItemTemplateIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariables",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemToolRules",
    "AgentsSearchResponseAgentsItemToolRulesItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemFour",
    "AgentsSearchResponseAgentsItemToolRulesItemFourType",
    "AgentsSearchResponseAgentsItemToolRulesItemItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemFour",
    "AgentsSearchResponseAgentsItemToolRulesItemItemFourType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemMaxCountLimit",
    "AgentsSearchResponseAgentsItemToolRulesItemItemMaxCountLimitType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwoType",
    "AgentsSearchResponseAgentsItemToolRulesItemMaxCountLimit",
    "AgentsSearchResponseAgentsItemToolRulesItemMaxCountLimitType",
    "AgentsSearchResponseAgentsItemToolRulesItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemTwoType",
    "AgentsSearchResponseAgentsItemToolsItem",
    "AgentsSearchResponseAgentsItemToolsItemArgsJsonSchema",
    "AgentsSearchResponseAgentsItemToolsItemArgsJsonSchemaItem",
    "AgentsSearchResponseAgentsItemToolsItemCreatedById",
    "AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemDescription",
    "AgentsSearchResponseAgentsItemToolsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchema",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemMetadata",
    "AgentsSearchResponseAgentsItemToolsItemMetadataItem",
    "AgentsSearchResponseAgentsItemToolsItemName",
    "AgentsSearchResponseAgentsItemToolsItemNameItem",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceCode",
    "AgentsSearchResponseAgentsItemToolsItemSourceCodeItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceType",
    "AgentsSearchResponseAgentsItemToolsItemSourceTypeItem",
    "AgentsSearchResponseAgentsItemToolsItemToolType",
    "AgentsSearchResponseAgentsItemUpdatedAt",
    "AgentsSearchResponseAgentsItemUpdatedAtItem",
    "AppAuthScheme",
    "AppAuthSchemeAuthMode",
    "AppModel",
    "AssistantMessage",
    "AssistantMessageContent",
    "AsyncLetta",
    "Audio",
    "AuthRequest",
    "AuthResponse",
    "AuthSchemeField",
    "Block",
    "BlockUpdate",
    "ChatCompletionAssistantMessageParam",
    "ChatCompletionAssistantMessageParamContent",
    "ChatCompletionAssistantMessageParamContentItem",
    "ChatCompletionAudioParam",
    "ChatCompletionAudioParamFormat",
    "ChatCompletionAudioParamVoice",
    "ChatCompletionContentPartImageParam",
    "ChatCompletionContentPartInputAudioParam",
    "ChatCompletionContentPartRefusalParam",
    "ChatCompletionContentPartTextParam",
    "ChatCompletionDeveloperMessageParam",
    "ChatCompletionDeveloperMessageParamContent",
    "ChatCompletionFunctionCallOptionParam",
    "ChatCompletionFunctionMessageParam",
    "ChatCompletionMessageToolCall",
    "ChatCompletionMessageToolCallParam",
    "ChatCompletionNamedToolChoiceParam",
    "ChatCompletionPredictionContentParam",
    "ChatCompletionPredictionContentParamContent",
    "ChatCompletionStreamOptionsParam",
    "ChatCompletionSystemMessageParam",
    "ChatCompletionSystemMessageParamContent",
    "ChatCompletionToolMessageParam",
    "ChatCompletionToolMessageParamContent",
    "ChatCompletionToolParam",
    "ChatCompletionUserMessageParam",
    "ChatCompletionUserMessageParamContent",
    "ChatCompletionUserMessageParamContentItem",
    "ChildToolRule",
    "CompletionCreateParamsNonStreaming",
    "CompletionCreateParamsNonStreamingFunctionCall",
    "CompletionCreateParamsNonStreamingMessagesItem",
    "CompletionCreateParamsNonStreamingModalitiesItem",
    "CompletionCreateParamsNonStreamingModel",
    "CompletionCreateParamsNonStreamingReasoningEffort",
    "CompletionCreateParamsNonStreamingResponseFormat",
    "CompletionCreateParamsNonStreamingServiceTier",
    "CompletionCreateParamsNonStreamingStop",
    "CompletionCreateParamsNonStreamingToolChoice",
    "CompletionCreateParamsStreaming",
    "CompletionCreateParamsStreamingFunctionCall",
    "CompletionCreateParamsStreamingMessagesItem",
    "CompletionCreateParamsStreamingModalitiesItem",
    "CompletionCreateParamsStreamingModel",
    "CompletionCreateParamsStreamingReasoningEffort",
    "CompletionCreateParamsStreamingResponseFormat",
    "CompletionCreateParamsStreamingServiceTier",
    "CompletionCreateParamsStreamingStop",
    "CompletionCreateParamsStreamingToolChoice",
    "ComponentsSchemasTextContent",
    "ConditionalToolRule",
    "ConflictError",
    "ConflictErrorBody",
    "ContextWindowOverview",
    "ContinueToolRule",
    "CoreMemoryBlockSchema",
    "CreateAgentRequestToolRulesItem",
    "CreateBlock",
    "CreateVoiceChatCompletionsRequest",
    "DeleteMcpServerResponseItem",
    "DynamicManager",
    "E2BSandboxConfig",
    "EmbeddingConfig",
    "EmbeddingConfigEmbeddingEndpointType",
    "File",
    "FileFile",
    "FileMetadata",
    "FunctionCall",
    "FunctionDefinitionInput",
    "FunctionDefinitionOutput",
    "FunctionOutput",
    "FunctionTool",
    "Group",
    "GroupCreate",
    "GroupCreateManagerConfig",
    "Health",
    "HttpValidationError",
    "Identity",
    "IdentityCreate",
    "IdentityProperty",
    "IdentityPropertyType",
    "IdentityPropertyValue",
    "IdentityType",
    "ImageUrl",
    "ImageUrlDetail",
    "InitToolRule",
    "InputAudio",
    "InputAudioFormat",
    "InternalServerError",
    "InternalServerErrorBody",
    "Job",
    "JobStatus",
    "JobType",
    "JsonSchema",
    "Letta",
    "LettaEnvironment",
    "LettaMessageContentUnion",
    "LettaMessageUnion",
    "LettaRequest",
    "LettaRequestConfig",
    "LettaResponse",
    "LettaStreamingRequest",
    "LettaUsageStatistics",
    "ListMcpServersResponseValue",
    "LlmConfig",
    "LlmConfigModelEndpointType",
    "LocalSandboxConfig",
    "ManagerType",
    "MaxCountPerStepToolRule",
    "McpServerType",
    "McpTool",
    "Memory",
    "Message",
    "MessageContentItem",
    "MessageCreate",
    "MessageCreateContent",
    "MessageCreateRole",
    "MessageRole",
    "MessageSchema",
    "NotFoundError",
    "NotFoundErrorBody",
    "NotFoundErrorBodyMessage",
    "OmittedReasoningContent",
    "OpenaiTypesChatChatCompletionMessageToolCallParamFunction",
    "OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction",
    "OpenaiTypesChatCompletionCreateParamsFunction",
    "Organization",
    "OrganizationCreate",
    "ParameterProperties",
    "ParametersSchema",
    "Passage",
    "PipRequirement",
    "Provider",
    "ReasoningContent",
    "ReasoningMessage",
    "ReasoningMessageSource",
    "RedactedReasoningContent",
    "ResponseFormatJsonObject",
    "ResponseFormatJsonSchema",
    "ResponseFormatText",
    "RoundRobinManager",
    "Run",
    "SandboxConfig",
    "SandboxConfigCreate",
    "SandboxConfigCreateConfig",
    "SandboxConfigUpdate",
    "SandboxConfigUpdateConfig",
    "SandboxEnvironmentVariable",
    "SandboxEnvironmentVariableCreate",
    "SandboxEnvironmentVariableUpdate",
    "SandboxType",
    "Source",
    "SseServerConfig",
    "StdioServerConfig",
    "Step",
    "SupervisorManager",
    "SystemMessage",
    "TagSchema",
    "TemplatesCreateAgentsResponse",
    "TemplatesCreateAgentsResponseAgentsItem",
    "TemplatesCreateAgentsResponseAgentsItemAgentType",
    "TemplatesCreateAgentsResponseAgentsItemBaseTemplateId",
    "TemplatesCreateAgentsResponseAgentsItemBaseTemplateIdItem",
    "TemplatesCreateAgentsResponseAgentsItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemIdentityIds",
    "TemplatesCreateAgentsResponseAgentsItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfig",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokens",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokensItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapper",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapperItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigTemperature",
    "TemplatesCreateAgentsResponseAgentsItemMemory",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemId",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemIsTemplate",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabel",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabelItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLimit",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemName",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemNameItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryPromptTemplate",
    "TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear",
    "TemplatesCreateAgentsResponseAgentsItemMessageIds",
    "TemplatesCreateAgentsResponseAgentsItemMessageIdsItem",
    "TemplatesCreateAgentsResponseAgentsItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentId",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerType",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurns",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurnsItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationToken",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationTokenItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem",
    "TemplatesCreateAgentsResponseAgentsItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemProjectId",
    "TemplatesCreateAgentsResponseAgentsItemProjectIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfig",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemId",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemTemplateId",
    "TemplatesCreateAgentsResponseAgentsItemTemplateIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRules",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildren",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildrenType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemFour",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemFourType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildren",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildrenType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFour",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFourType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimit",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimitType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOne",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwo",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwoType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimit",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimitType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemOne",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemOneType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwo",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwoType",
    "TemplatesCreateAgentsResponseAgentsItemToolsItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchema",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchemaItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchemaItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemName",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCodeItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceTypeItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemToolType",
    "TemplatesCreateAgentsResponseAgentsItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemUpdatedAtItem",
    "TerminalToolRule",
    "TextContent",
    "Tool",
    "ToolCall",
    "ToolCallContent",
    "ToolCallDelta",
    "ToolCallMessage",
    "ToolCallMessageToolCall",
    "ToolCreate",
    "ToolEnvVarSchema",
    "ToolJsonSchema",
    "ToolReturn",
    "ToolReturnContent",
    "ToolReturnMessage",
    "ToolReturnMessageStatus",
    "ToolReturnStatus",
    "ToolRuleSchema",
    "ToolSchema",
    "ToolType",
    "UnprocessableEntityError",
    "UpdateAgentToolRulesItem",
    "UpdateAssistantMessage",
    "UpdateAssistantMessageContent",
    "UpdateReasoningMessage",
    "UpdateSystemMessage",
    "UpdateUserMessage",
    "UpdateUserMessageContent",
    "UsageStatistics",
    "User",
    "UserCreate",
    "UserMessage",
    "UserMessageContent",
    "UserUpdate",
    "ValidationError",
    "ValidationErrorLocItem",
    "WebSearchOptions",
    "WebSearchOptionsSearchContextSize",
    "WebSearchOptionsUserLocation",
    "WebSearchOptionsUserLocationApproximate",
    "__version__",
    "agents",
    "blocks",
    "groups",
    "health",
    "identities",
    "jobs",
    "models",
    "providers",
    "runs",
    "sources",
    "steps",
    "tag",
    "templates",
    "tools",
    "voice",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_max_turns_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem,
)

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns = typing.Union[
    float,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem]],
    typing.Optional[typing.Any],
]
